==> mono_1.1.8.2.orig.tar.gz: mono-1.1.8.2/mcs/class/corlib/System.Runtime.InteropServices/UnmanagedFunctionPointerAttribute.cs <==
//
// System.Runtime.InteropServices.UnmanagedFunctionPointerAttribute.cs
//
// Author:
//   Zoltan Varga (vargaz@gmail.com)
//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;

namespace System.Runtime.InteropServices {

	[AttributeUsage (AttributeTargets.Delegate, Inherited = false)]
	public sealed class UnmanagedFunctionPointerAttribute: Attribute {
		#region Sync with object-internals.h
		private CallingConvention call_conv;
		public CharSet CharSet;
		public bool SetLastError;
		public bool BestFitMapping;
		public bool ThrowOnUnmappableChar;
		#endregion

		public CallingConvention CallingConvention {
			get {
				return call_conv;
			}
		}
		
		public UnmanagedFunctionPointerAttribute (CallingConvention call_conv) {
			this.call_conv = call_conv;
		}
	}
}

#endif

==> mono_1.9.1+dfsg.orig.tar.gz: mono-1.9.1+dfsg/mcs/class/corlib/System.Runtime.InteropServices/UnmanagedFunctionPointerAttribute.cs <==
//
// System.Runtime.InteropServices.UnmanagedFunctionPointerAttribute.cs
//
// Author:
//   Zoltan Varga (vargaz@gmail.com)
//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;

namespace System.Runtime.InteropServices {

	[AttributeUsage (AttributeTargets.Delegate, Inherited = false,AllowMultiple=false),ComVisible(true)]
	public sealed class UnmanagedFunctionPointerAttribute: Attribute {
		#region Sync with object-internals.h
		private CallingConvention call_conv;
		public CharSet CharSet;
		public bool SetLastError;
		public bool BestFitMapping;
		public bool ThrowOnUnmappableChar;
		#endregion

		public CallingConvention CallingConvention {
			get {
				return call_conv;
			}
		}
		
		public UnmanagedFunctionPointerAttribute (CallingConvention callingConvention) {
			this.call_conv = callingConvention;
		}
	}
}

#endif
